@@ -21,6 +21,7 @@
 #define KITEMLISTHEADER_H
 
 #include "dolphin_export.h"
+
 #include <QHash>
 #include <QObject>
 
@@ -38,7 +39,7 @@ class DOLPHIN_EXPORT KItemListHeader : public QObject
     Q_OBJECT
 
 public:
-    virtual ~KItemListHeader();
+    ~KItemListHeader() override;
 
     /**
      * If set to true, KItemListView will automatically adjust the
@@ -87,7 +88,7 @@ signals:
                                    qreal currentWidth);
 
 private:
-    KItemListHeader(KItemListView* listView);
+    explicit KItemListHeader(KItemListView* listView);
 
 private:
     KItemListView* m_view;
