@@ -20,7 +20,6 @@
 #include "placesitemsignalhandler.h"
 
 #include "placesitem.h"
-#include <Solid/StorageAccess>
 
 PlacesItemSignalHandler::PlacesItemSignalHandler(PlacesItem* item,
                                                  QObject* parent) :
@@ -40,13 +39,6 @@ void PlacesItemSignalHandler::onAccessibilityChanged()
     }
 }
 
-void PlacesItemSignalHandler::onTrashDirListerCompleted()
-{
-    if (m_item) {
-        m_item->onTrashDirListerCompleted();
-    }
-}
-
 void PlacesItemSignalHandler::onTearDownRequested(const QString& udi)
 {
     Q_UNUSED(udi)
