@@ -48,7 +48,7 @@ class PlacesItemSignalHandler: public QObject
 
 public:
     explicit PlacesItemSignalHandler(PlacesItem* item, QObject* parent = nullptr);
-    virtual ~PlacesItemSignalHandler();
+    ~PlacesItemSignalHandler() override;
 
 public slots:
     /**
@@ -56,11 +56,6 @@ public slots:
      */
     void onAccessibilityChanged();
 
-    /**
-     * Calls PlacesItem::onTrashDirListerCompleted()
-     */
-    void onTrashDirListerCompleted();
-
     void onTearDownRequested(const QString& udi);
 
 signals:
